@@ -1,9 +1,10 @@
 import time
 from datetime import datetime
-from ..core import ChepyCore
+from ..core import ChepyCore, ChepyDecorators
 
 
 class DateTime(ChepyCore):
+    @ChepyDecorators.call_stack
     def from_unix_ts(self):
         """Convert UNIX timestamp to datetime
         
@@ -17,6 +18,7 @@ class DateTime(ChepyCore):
         self.state = datetime.fromtimestamp(self._convert_to_int()).strftime("%c")
         return self
 
+    @ChepyDecorators.call_stack
     def to_unix_ts(self):  # pragma: no cover
         """Convert datetime string to unix ts
 
