@@ -1,7 +1,7 @@
 import sys
 import inspect
+import regex as re
 from pprint import pformat, pprint
-from subprocess import getoutput
 
 from docstring_parser import parse as _parse_doc
 from prompt_toolkit.completion import Completer, Completion
@@ -10,9 +10,12 @@ from prompt_toolkit.styles import Style
 from prompt_toolkit.formatted_text import FormattedText
 
 from chepy import Chepy
+from chepy.config import ChepyConfig
+from chepy.modules.internal.colors import yellow, red, yellow_background
 
 module = sys.modules[__name__]
 options = []
+config = ChepyConfig()
 
 
 class CliCompleter(Completer):
@@ -66,6 +69,33 @@ def functions_cli():
     return functions
 
 
+def get_doc(method: str):
+    """Get docs for a method"""
+    try:
+        print(yellow(getattr(Chepy, method).__doc__))
+    except:
+        print(red(pformat("Could not find docs...")))
+
+
+def cli_highlight(fire: object, highlight: str):
+    """Highlight regex match for cli
+    
+    Args:
+        fire (object): The fire object.
+        highlight (str): Regex to highlight
+    """
+    current_state = fire.states[fire._current_index]
+    if fire is not None and isinstance(fire, Chepy):
+        try:
+            print(re.sub('({})'.format(highlight), yellow_background(r'\1'), str(current_state)))
+        except:
+            red('Could not highlight because state is not a string')
+        # elif type(current_state) == bytes or type(current_state) == bytearray:
+        #     print(re.sub('({})'.format(highlight).encode(), red(r'\1').encode(), current_state).decode())
+    else:
+        print(type(fire))
+
+
 def get_cli_options():
     options = dict()
     for method in functions_cli():
@@ -100,7 +130,7 @@ def get_cli_options():
 
 
 def print_in_colors(out):
-    style = Style.from_dict({"cli_out": "fg:#ffb4ad"})
+    style = Style.from_dict({"cli_out": "fg:{}".format(config.cli_info_color)})
     print_formatted_text(FormattedText([("class:cli_out", str(out))]), style=style)
 
 
@@ -124,11 +154,33 @@ def cli_get_state(fire: object, index: int):
         index (int): Required. The index for the state
     """
     if fire is not None and isinstance(fire, Chepy):
-        print_in_colors(fire.states[int(0)])
+        print_in_colors(fire.states[int(index)])
     else:
         print(type(fire))
 
 
+def cli_show_length(fire: object):
+    """Get the length of the current state.
+
+    Args:
+        fire (object): The fire object
+    """
+    print_in_colors(len(fire.state))
+
+
+def cli_show_dict_keys(fire: object, pretty: bool = False):
+    """Get the dict keys of the current state.
+
+    Args:
+        fire (object): The fire object
+        pretty (bool): Pretty print output. Defaults to False
+    """
+    if pretty:
+        print_in_colors(pformat(list(fire.state.keys())))
+    else:
+        print_in_colors(fire.state.keys())
+
+
 def cli_show_states(fire: object, pretty: bool = False):
     """Change the current state
     
@@ -171,7 +223,7 @@ def cli_get_attr(fire: object, attr: str):
     if fire is not None and not isinstance(fire, Chepy):
         print_in_colors(getattr(fire, attr)())
     else:
-        print("nope")
+        print(red("Nope. That didnt work.."))
 
 
 def cli_pretty_print(fire: object):
@@ -183,7 +235,13 @@ def cli_pretty_print(fire: object):
     if fire is not None and isinstance(fire, Chepy):
         print_in_colors(pformat(fire.state))
     else:
-        print("nope")
+        print(red("Nope. That didnt work.."))
+
+
+def cli_plugin_path(config):
+    """Print the current plugin path
+    """
+    print(yellow(str(config.plugin_path)))
 
 
 def cli_show_errors(errors):
